@@ -1,6 +1,4 @@
 package BibTeX::Parser::Entry;
-our $VERSION = '0.3.2';
-
 
 use warnings;
 use strict;
@@ -13,10 +11,13 @@ BibTeX::Entry - Contains a single entry of a BibTeX document.
 
 =head1 VERSION
 
-version 0.3.2
+Version 0.01
 
 =cut
 
+our $VERSION = '0.2';
+
+
 =head1 SYNOPSIS
 
 This class ist a wrapper for a single BibTeX entry. It is usually created
@@ -52,7 +53,6 @@ sub new {
 	$fields{_type}     = uc($type);
 	$fields{_key}      = $key;
 	$fields{_parse_ok} = $parse_ok;
-        $fields{_raw}      = '';
 	return bless \%fields, $class;
 }
 
@@ -234,19 +234,60 @@ sub _sanitize_field {
 	return $value;
 }
 
+=head1 AUTHOR
 
-=head2 raw_bibtex
+Gerhard Gossen, C<< <gerhard.gossen at googlemail.com> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-bibtex-entry at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=BibTeX-Parser>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc BibTeX::Parser
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=BibTeX-Parser>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/BibTeX-Parser>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/BibTeX-Parser>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/BibTeX-Parser>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Gerhard Gossen, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
-Return raw BibTeX entry (if available).
 
 =cut
 
-sub raw_bibtex {
-	my $self = shift;
-	if (@_) {
-		$self->{_raw} = shift;
-	}
-	return $self->{_raw};
-}
-
-1; # End of BibTeX::Entry
\ No newline at end of file
+1; # End of BibTeX::Entry
